@@ -64,6 +64,13 @@ class Pool(MinerConfigValue):
             f"passwd_{idx}": self.password,
         }
 
+    def as_btminer_v3(self, user_suffix: str | None = None) -> dict:
+        return {
+            f"pool": self.url,
+            f"worker": f"{self.user}{user_suffix or ''}",
+            f"passwd": self.password,
+        }
+
     def as_am_old(self, idx: int = 1, user_suffix: str | None = None) -> dict:
         return {
             f"_ant_pool{idx}url": self.url,
@@ -148,6 +155,10 @@ class Pool(MinerConfigValue):
     def from_api(cls, api_pool: dict) -> "Pool":
         return cls(url=api_pool["URL"], user=api_pool["User"], password="x")
 
+    @classmethod
+    def from_btminer_v3(cls, api_pool: dict) -> "Pool":
+        return cls(url=api_pool["url"], user=api_pool["account"], password="x")
+
     @classmethod
     def from_epic(cls, api_pool: dict) -> "Pool":
         return cls(
@@ -296,6 +307,9 @@ class PoolGroup(MinerConfigValue):
             idx += 1
         return pools
 
+    def as_btminer_v3(self, user_suffix: str | None = None) -> list:
+        return [pool.as_btminer_v3(user_suffix) for pool in self.pools[:3]]
+
     def as_am_old(self, user_suffix: str | None = None) -> dict:
         pools = {}
         idx = 0
@@ -385,6 +399,13 @@ class PoolGroup(MinerConfigValue):
             pools.append(Pool.from_api(pool))
         return cls(pools=pools)
 
+    @classmethod
+    def from_btminer_v3(cls, api_pool_list: list) -> "PoolGroup":
+        pools = []
+        for pool in api_pool_list:
+            pools.append(Pool.from_btminer_v3(pool))
+        return cls(pools=pools)
+
     @classmethod
     def from_epic(cls, api_pool_list: list) -> "PoolGroup":
         pools = []
@@ -513,6 +534,11 @@ class PoolConfig(MinerConfigValue):
             return {"pools": self.groups[0].as_wm(user_suffix=user_suffix)}
         return {"pools": PoolGroup().as_wm()}
 
+    def as_btminer_v3(self, user_suffix: str | None = None) -> dict:
+        if len(self.groups) > 0:
+            return {"pools": self.groups[0].as_btminer_v3(user_suffix=user_suffix)}
+        return {"pools": PoolGroup().as_btminer_v3()}
+
     def as_am_old(self, user_suffix: str | None = None) -> dict:
         if len(self.groups) > 0:
             return self.groups[0].as_am_old(user_suffix=user_suffix)
@@ -598,6 +624,16 @@ class PoolConfig(MinerConfigValue):
 
         return cls(groups=[PoolGroup.from_api(pool_data)])
 
+    @classmethod
+    def from_btminer_v3(cls, rpc_pools: dict) -> "PoolConfig":
+        try:
+            pool_data = rpc_pools["pools"]
+        except KeyError:
+            return PoolConfig.default()
+        pool_data = sorted(pool_data, key=lambda x: int(x["id"]))
+
+        return cls(groups=[PoolGroup.from_btminer_v3(pool_data)])
+
     @classmethod
     def from_epic(cls, web_conf: dict) -> "PoolConfig":
         pool_data = web_conf["StratumConfigs"]
@@ -631,6 +667,16 @@ class PoolConfig(MinerConfigValue):
     def from_goldshell(cls, web_pools: list) -> "PoolConfig":
         return cls(groups=[PoolGroup.from_goldshell(web_pools)])
 
+    @classmethod
+    def from_goldshell_byte(cls, web_pools: list) -> "PoolConfig":
+        return cls(
+            groups=[
+                PoolGroup.from_goldshell(g["pools"])
+                for g in web_pools
+                if len(g["pools"]) > 0
+            ]
+        )
+
     @classmethod
     def from_inno(cls, web_pools: list) -> "PoolConfig":
         return cls(groups=[PoolGroup.from_inno(web_pools)])
