@@ -17,6 +17,9 @@
 from .bmminer import *
 from .bosminer import *
 from .cgminer import *
+from .epic import *
 from .hiveon import *
 from .luxos import *
+from .marathon import *
+from .mskminer import *
 from .vnish import *
