@@ -15,9 +15,7 @@
 # ------------------------------------------------------------------------------
 
 from pyasic.miners.backends import AntminerModern
-from pyasic.miners.types import T19
-
-# noqa - Ignore access to _module
+from pyasic.miners.device.models import T19
 
 
 class BMMinerT19(AntminerModern, T19):
