@@ -305,10 +305,12 @@ class AvalonMiner(CGMiner):
                     hashboards[board].chip_temp = int(
                         parsed_estats["STATS"][0]["MM ID0"]["MTmax"][board]
                     )
-                except LookupError:
+                except (LookupError, TypeError):
                     try:
                         hashboards[board].chip_temp = int(
-                            parsed_estats["STATS"][0]["MM ID0"]["Tmax"]
+                            parsed_estats["STATS"][0]["MM ID0"].get(
+                                "Tmax", parsed_estats["STATS"][0]["MM ID0"]["TMax"]
+                            )
                         )
                     except LookupError:
                         pass
@@ -317,10 +319,12 @@ class AvalonMiner(CGMiner):
                     hashboards[board].temp = int(
                         parsed_estats["STATS"][0]["MM ID0"]["MTmax"][board]
                     )
-                except LookupError:
+                except (LookupError, TypeError):
                     try:
                         hashboards[board].temp = int(
-                            parsed_estats["STATS"][0]["MM ID0"]["Tavg"]
+                            parsed_estats["STATS"][0]["MM ID0"].get(
+                                "Tavg", parsed_estats["STATS"][0]["MM ID0"]["TAvg"]
+                            )
                         )
                     except LookupError:
                         pass
@@ -329,7 +333,7 @@ class AvalonMiner(CGMiner):
                     hashboards[board].inlet_temp = int(
                         parsed_estats["STATS"][0]["MM ID0"]["MTavg"][board]
                     )
-                except LookupError:
+                except (LookupError, TypeError):
                     try:
                         hashboards[board].inlet_temp = int(
                             parsed_estats["STATS"][0]["MM ID0"]["HBITemp"]
@@ -341,7 +345,7 @@ class AvalonMiner(CGMiner):
                     hashboards[board].outlet_temp = int(
                         parsed_estats["STATS"][0]["MM ID0"]["MTmax"][board]
                     )
-                except LookupError:
+                except (LookupError, TypeError):
                     try:
                         hashboards[board].outlet_temp = int(
                             parsed_estats["STATS"][0]["MM ID0"]["HBOTemp"]
@@ -356,7 +360,7 @@ class AvalonMiner(CGMiner):
                         hashboards[board].chips = len(
                             [item for item in chip_data if not item == "0"]
                         )
-                except LookupError:
+                except (LookupError, TypeError):
                     try:
                         chip_data = parsed_estats["STATS"][0]["HBinfo"][f"HB{board}"][
                             f"PVT_T{board}"
